==> enterprisemodules-wls_install-3.4.2.tar.gz: enterprisemodules-wls_install-3.4.2/README.md <==

[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the wls_install module](#installing-the-wls_install-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to install an Oracle WebLogic or Fusion middleware stack. It is part of our family of Puppet modules to install, manage and secure Oracle WebLogic and Fusion Middleware with Puppet. Besides the [`wls_install`](https://www.enterprisemodules.com/shop/products/puppet-wls_install-module) module, this family also contains:

- [wls_config](https://www.enterprisemodules.com/shop/products/puppet-wls_config-module) For configuring an Oracle WebLogic and other Fusion products

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. You can [request a **FREE** trial license here](https://www.enterprisemodules.com/sign-up-for-free-trial)

[![FREE TRIAL](https://raw.githubusercontent.com/enterprisemodules/public_images/master/free-trial.jpg)](https://www.enterprisemodules.com/sign-up-for-free-trial)

Check the [License](https://forge.puppet.com/enterprisemodules/ora_install/license) for details.
## Description

This Puppet module allows you to install Oracle WebLogic and other products in the Oracle Fusion Middleware family.

### Fusion Middleware Features 11g & 12.1.3

- installs FMW software(add-on) to a middleware home, like OSB,SOA Suite, Oracle Identity & Access Management, Oracle Unified Directory, WebCenter Portal + Content
- WebTier Oracle HTTP server
- OSB, SOA Suite with BPM and BAM Cluster configuration support ( convert single osb/soa/bam servers to clusters and migrate OPSS to the database )
- ADF/JRF support, Assign JRF libraries to a Server or Cluster target
- IDM/OAM configurations with Oracle OHS OAM WebGate, Also Cluster support for OIM OAM
- OUD Oracle Unified Directory install, WebLogic domain, instances creation & OUD control
- Forms/Reports Oracle Forms & Reports 11.1.1.7 or 11.1.2
- Change FMW log location of a managed server
- Resource Adapterplan and entries for AQ, DB File and JMS

This module supports the installation of WebLogic versions:
- 10g
- 11g
- 12c( 12.1.1 & 12.1.2 & 12.1.3 + FMW infra )

### Basic Domain Management

We support the creation of a domain. You can create different types of domains:
- default WebLogic
- JRF + EM + Coherence (12.1.2 & 12.1.3) + OWSM (12.1.2 & 12.1.3) + JAX-WS Advanced + Soap over JMS
- OSB + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- OSB + SOA Suite + BAM + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- OSB + SOA Suite + BAM + BPM + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- SOA Suite + BAM + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- SOA Suite + BAM + BPM + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- WC (webcenter) + WCC ( Content ) + BPM + JRF + EM + OWSM
- WC (webcenter) + JRF + EM + OWSM
- OIM (Oracle Identity Manager) + OAM ( Oracle Access Manager)
- OUD (Oracle Unified Directory)

The modules also allow you to pack a domain and copy it to an other node in a cluster.

### Security

The module has support for Java Secure Socket Extension support(JSSE) and Custom Identity and Trust Store support]

### Startup and shutdown

- Startup a nodemanager
- Start or stop AdminServer, Managed or a Cluster
- Storing WebLogic Credentials and using in WLST

### Miscellaneous

- Linux low on entropy or urandom fix
- Dynamic targetting] by using the notes field in WebLogic for resource targetting

Check [here](https://www.enterprisemodules.com/docs/wls_install/description.html) to see the full documentation for this module.

## Setup

### Requirements

The [`wls_install`](https://www.enterprisemodules.com/shop/products/puppet-wls_install-module) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 4.10.8 or higher. Can be Puppet Enterprise or Puppet Open Source
- WebLogic 10g or higher
- A valid Oracle Weblogic or Fusion license
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Runs on Solaris
- Windows systems are **NOT** supported

We support WebLogic versions:

- WebLogic 10g
- WebLogic 11g
- WebLogic 12.1.2
- WebLogic 12.1.3
- WebLogic 12.2.1
- WebLogic 12.2.1.1
- WebLogic 12.2.1.2
- WebLogic 12.2.1.3

And Fusion versions:

- WebLogic 10g
- WebLogic 11g
- WebLogic 12c ( 12.1.1, 12.1.2, 12.1.3, 12.2.1, 12.2.1.1, 12.2.1.2, 12.2.1.3)

### Installing the wls_install module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/wls_install'               ,'3.0.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-wls_install
```

## Usage

Building a total WebLogic or Fusion setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_wls_demo). The repo contains a demonstration of a simple WebLogic installation. 

## Reference

Here you can find some more information regarding this puppet module:
- [The `wls_install` documentation](https://www.enterprisemodules.com/docs/wls_install/description.html)
- [The `wls_config` documentation](https://www.enterprisemodules.com/docs/wls_config/description.html)

Here are a related blog posts:
- [Introducing version 3 of wls_config](https://www.enterprisemodules.com//blog/2016/05/introducing-version-3-of-wls-config/)
- [Know thy WebLogic configuration using Puppet](https://www.enterprisemodules.com//blog/2016/01/know-thy-weblogic-configuration-using-puppet/)
- [Manage your WebLogic JMS config with Puppet](https://www.enterprisemodules.com//blog/2016/01/manage-your-weblogic-jms-config-with-puppet/)
- [Using Puppet to install and manage your WebLogic infrastructure](https://www.enterprisemodules.com//blog/2015/11/using-puppet-to-configure-your-weblogic-infrastructure/)

Some example code:
- [Simple WLS demo](https://github.com/enterprisemodules/simple_wls_demo)
- [Simple osb demo](https://github.com/enterprisemodules/simple_osb_demo)
- [Simple soa demo](https://github.com/enterprisemodules/simple_soa_demo)

## Limitations

This module runs on Solaris and most Linux versions. It requires a puppet version higher than 4.10.8. The module does **NOT** run on windows systems.

==> enterprisemodules-wls_install-3.7.3.tar.gz: enterprisemodules-wls_install-3.7.3/README.md <==

[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the wls_install module](#installing-the-wls_install-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to install an Oracle WebLogic or Fusion middleware stack. It is part of our family of Puppet modules to install, manage and secure Oracle WebLogic and Fusion Middleware with Puppet. Besides the [`wls_install`](https://www.enterprisemodules.com/shop/products/puppet-wls_install-module) module, this family also contains:

- [wls_config](https://www.enterprisemodules.com/shop/products/puppet-wls_config-module) For configuring an Oracle WebLogic and other Fusion products

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. You can [request a **FREE** trial license here](https://www.enterprisemodules.com/sign-up-for-free-trial)

[![FREE TRIAL](https://raw.githubusercontent.com/enterprisemodules/public_images/master/free-trial.jpg)](https://www.enterprisemodules.com/sign-up-for-free-trial)

Check the [License](https://forge.puppet.com/enterprisemodules/ora_install/license) for details.
## Description

This Puppet module allows you to install Oracle WebLogic and other products in the Oracle Fusion Middleware family.

### Fusion Middleware Features 11g & 12.1.3

- installs FMW software(add-on) to a middleware home, like OSB,SOA Suite, Oracle Identity & Access Management, Oracle Unified Directory, WebCenter Portal + Content
- WebTier Oracle HTTP server
- OSB, SOA Suite with BPM and BAM Cluster configuration support ( convert single osb/soa/bam servers to clusters and migrate OPSS to the database )
- ADF/JRF support, Assign JRF libraries to a Server or Cluster target
- IDM/OAM configurations with Oracle OHS OAM WebGate, Also Cluster support for OIM OAM
- OUD Oracle Unified Directory install, WebLogic domain, instances creation & OUD control
- Forms/Reports Oracle Forms & Reports 11.1.1.7 or 11.1.2
- Change FMW log location of a managed server
- Resource Adapterplan and entries for AQ, DB File and JMS

This module supports the installation of WebLogic versions:
- 10g
- 11g
- 12c( 12.1.1 & 12.1.2 & 12.1.3 + FMW infra )

### Basic Domain Management

We support the creation of a domain. You can create different types of domains:
- default WebLogic
- JRF + EM + Coherence (12.1.2 & 12.1.3) + OWSM (12.1.2 & 12.1.3) + JAX-WS Advanced + Soap over JMS
- OSB + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- OSB + SOA Suite + BAM + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- OSB + SOA Suite + BAM + BPM + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- SOA Suite + BAM + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- SOA Suite + BAM + BPM + JRF + EM + OWSM + ESS ( optional with 12.1.3 )
- WC (webcenter) + WCC ( Content ) + BPM + JRF + EM + OWSM
- WC (webcenter) + JRF + EM + OWSM
- OIM (Oracle Identity Manager) + OAM ( Oracle Access Manager)
- OUD (Oracle Unified Directory)

The modules also allow you to pack a domain and copy it to an other node in a cluster.

### Security

The module has support for Java Secure Socket Extension support(JSSE) and Custom Identity and Trust Store support]

### Startup and shutdown

- Startup a nodemanager
- Start or stop AdminServer, Managed or a Cluster
- Storing WebLogic Credentials and using in WLST

### Miscellaneous

- Linux low on entropy or urandom fix
- Dynamic targetting] by using the notes field in WebLogic for resource targetting

Check [here](https://www.enterprisemodules.com/docs/wls_install/description.html) to see the full documentation for this module.

## Setup

### Requirements

The [`wls_install`](https://www.enterprisemodules.com/shop/products/puppet-wls_install-module) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 4.10.8 or higher. Can be Puppet Enterprise or Puppet Open Source
- WebLogic 10g or higher
- A valid Oracle Weblogic or Fusion license
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Runs on Solaris
- Windows systems are **NOT** supported

We support WebLogic versions:

- WebLogic 10g
- WebLogic 11g
- WebLogic 12.1.2
- WebLogic 12.1.3
- WebLogic 12.2.1
- WebLogic 12.2.1.1
- WebLogic 12.2.1.2
- WebLogic 12.2.1.3
- WebLogic 12.2.1.4

And Fusion versions:

- WebLogic 10g
- WebLogic 11g
- WebLogic 12c ( 12.1.1, 12.1.2, 12.1.3, 12.2.1, 12.2.1.1, 12.2.1.2, 12.2.1.3, 12.2.1.4)

### Installing the wls_install module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/wls_install'               ,'3.0.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-wls_install
```

## Usage

Building a total WebLogic or Fusion setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_wls_demo). The repo contains a demonstration of a simple WebLogic installation. 

## Reference

Here you can find some more information regarding this puppet module:
- [The `wls_install` documentation](https://www.enterprisemodules.com/docs/wls_install/description.html)
- [The `wls_config` documentation](https://www.enterprisemodules.com/docs/wls_config/description.html)

Here are a related blog posts:
- [Introducing version 3 of wls_config](https://www.enterprisemodules.com//blog/2016/05/introducing-version-3-of-wls-config/)
- [Know thy WebLogic configuration using Puppet](https://www.enterprisemodules.com//blog/2016/01/know-thy-weblogic-configuration-using-puppet/)
- [Manage your WebLogic JMS config with Puppet](https://www.enterprisemodules.com//blog/2016/01/manage-your-weblogic-jms-config-with-puppet/)
- [Using Puppet to install and manage your WebLogic infrastructure](https://www.enterprisemodules.com//blog/2015/11/using-puppet-to-configure-your-weblogic-infrastructure/)

Some example code:
- [Simple WLS demo](https://github.com/enterprisemodules/simple_wls_demo)
- [Simple osb demo](https://github.com/enterprisemodules/simple_osb_demo)
- [Simple soa demo](https://github.com/enterprisemodules/simple_soa_demo)

## Limitations

This module runs on Solaris and most Linux versions. It requires a puppet version higher than 4.10.8. The module does **NOT** run on windows systems.
